from PIL import Image
from flask import Flask, request
from flask_restful import Resource, Api
import Adafruit_DHT
import json
import RPi.GPIO as GPIO
import time
import matplotlib.pyplot as mpl
from formSense import SenseForm
from flask import render_template
'''
Python DHT11 Temp and Humidity Sensor 
	Ryan Fleming and Austin McManus
'''
app = Flask(__name__)
app.config['SECRET_KEY']= 'WSAT'
api = Api(app)
sensor = Adafruit_DHT.DHT11

class SenseObject:
	def __init__(self):
		self.temperature = 0
		self.humidity = 0
		self.in1 = 18
		GPIO.setmode(GPIO.BCM)
		GPIO.setup(self.in1,GPIO.OUT)

	def getTemp(self):
		humidity, temp = Adafruit_DHT.read_retry(sensor, self.in1)
		return(int(temp))

	def getHumid(self):
		humidity, temp = Adafruit_DHT.read_retry(sensor,self.in1)
		return(int(humidity))


def Graph(temp, time, humidity):
	print(temp)
	print(time)
	mpl.plot(time, humidity, label="Humidity")
	mpl.plot(time, temp, label = "Temperature")
	mpl.xlabel = "Time"
	mpl.ylabel = "Degrees Celcius/ Percent Humidity"
	mpl.legend(loc= "center right")
	mpl.title("Daily Temperature  and Humidity")
	mpl.savefig("./static/CurrentStatGraph.png")
	return("./static/CurrentStatGraph.png")

theSense = SenseObject()
tempList = []
tList = []
humList = []
def updateData(t):
	t=t%86400
	t=t/3600
	humidity,temp = Adafruit_DHT.read_retry(sensor,18)
	if len(tempList)<24:
		tempList.append(int(temp))
		tList.append(t)
		humList.append(int(humidity))
	else:
		index = len(tempList)%24
		tempList[index] = int(temp)
		tList[index] = t
		humList[index] = int(humidity)

controlDict = {"Temperature":"none", "Humidity":"none", "Graph":"none"}
@app.route("/control", methods = ["POST","GET","PUT"])
def control():
	error=None
	theSense.temperature = controlDict['Temperature']
	theSense.humidity = controlDict['Humidity']
	pair= theSense.process()
	return render_template('sense.html',title= "Weather Sensor IoT Device Webpage", cDict= controlDict, form = form)
@app.route("/getdata", methods = ["POST","GET","PUT"])
def dataroute():
	return "Gathering Data"

@app.route("/sense.html", methods = ["POST","GET","PUT"])
def sense():
	controlDict = {"Temperature":"none","Humidity":"none","Graph":"none"}
	form = SenseForm()
	updateData(time.time())
	if request.method =="POST":
		if(form.temperature.data==True):
			controlDict['Temperature'] = theSense.getTemp()
		if(form.humidity.data==True):
			controlDict['Humidity'] = theSense.getHumid()
		if form.graph.data == True:
			controlDict["Graph"] = 1
			imageName = Graph(tempList,tList, humList)
	if controlDict['Temperature'] !="none" and controlDict['Humidity']=='none' and controlDict['Graph']=='none':
		return render_template('sense_tem.html', title = "Weather Sensor IoT Device Webpage",cDict=controlDict, form= form)
	elif controlDict['Temperature'] =="none" and controlDict["Humidity"]!="none" and controlDict['Graph']=='none':
		return render_template('sense_hum.html', title= "Weather Sensor IoT Device Webpage", cDict= controlDict, form= form)
	elif controlDict['Temperature']=='none' and controlDict['Humidity']=="none" and controlDict["Graph"]!="none":
		return render_template('sense_graph.html', title= "Weather Sensor IoT Device Webpage", imageTitle=imageName,form=form)
	elif controlDict['Temperature']!='none' and controlDict['Humidity']!='none'and controlDict['Graph']=='none':
		return render_template('sense_tem_hum.html', title = "Weather Sensor IoT Device Webpage", cDict = controlDict, form= form)
	elif controlDict['Temperature']!='none' and controlDict['Humidity']=='none' and controlDict['Graph']!='none':
		return render_template('sense_tem_graph.html', title="Weahter Sensor IoT Device Webpage",cDict=controlDict, imageTitle=imageName,form=form)
	elif controlDict['Temperature']=='none' and controlDict['Humidity']!='none' and controlDict['Graph']!='none':
		return render_template('sense_hum_graph.html', title="Weather Sensor IoT Device Webpage", cDict=controlDict, imageTitle=imageName,form=form)
	elif controlDict['Temperature']!='none' and controlDict['Humidity']!='none' and controlDict['Graph']!= 'none':
		return render_template('sense_tem_hum_graph.html', title = "Weather Sensor IoT Device Webpage",imageTitle=imageName, cDict=controlDict, form = form)
	else:
		return render_template('sense.html', title='Weather Sensor IoT Device Webpage', form=form)

if __name__ =="__main__":
	app.run(host = '0.0.0.0')
